@@ -1,7 +1,7 @@
 # -*- shell-script -*-
 # disable.sh - gdb-like "disable" debugger command
 #
-#   Copyright (C) 2008, 2009, 2011 Rocky Bernstein <rocky@gnu.org>
+#   Copyright (C) 2008, 2009, 2011, 2016 Rocky Bernstein <rocky@gnu.org>
 #
 #   This program is free software; you can redistribute it and/or
 #   modify it under the terms of the GNU General Public License as
@@ -19,11 +19,14 @@
 #   MA 02111 USA.
 
 _Dbg_help_add disable \
-'disable BPNUM1 [BPNUM2 ...]
+'**disable** *bpnumber* [*bpnumber* ...]
 
-Disable breakpoint BPNUM.
+Disables the breakpoints given as a space separated list of breakpoint numbers.
 
-See also "enable" and "info break".'
+See also:
+---------
+
+**enable** and **info break**.'
 
 # Disable breakpoint(s)/watchpoint(s) by entry number(s).
 _Dbg_do_disable() {
